==> zio-aws-pinpointemail_2.12-5.17.151.2-sources.jar: zio/aws/pinpointemail/model/PutEmailIdentityMailFromAttributesRequest.scala <==
package zio.aws.pinpointemail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpointemail.model.primitives.{MailFromDomainName, Identity}
import scala.jdk.CollectionConverters._
final case class PutEmailIdentityMailFromAttributesRequest(
    emailIdentity: Identity,
    mailFromDomain: Option[MailFromDomainName] = None,
    behaviorOnMxFailure: Option[
      zio.aws.pinpointemail.model.BehaviorOnMxFailure
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest = {
    import PutEmailIdentityMailFromAttributesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest
      .builder()
      .emailIdentity(Identity.unwrap(emailIdentity): java.lang.String)
      .optionallyWith(
        mailFromDomain.map(value =>
          MailFromDomainName.unwrap(value): java.lang.String
        )
      )(_.mailFromDomain)
      .optionallyWith(behaviorOnMxFailure.map(value => value.unwrap))(
        _.behaviorOnMxFailure
      )
      .build()
  }
  def asReadOnly
      : zio.aws.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest.ReadOnly =
    zio.aws.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest
      .wrap(buildAwsValue())
}
object PutEmailIdentityMailFromAttributesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest =
      zio.aws.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest(
        emailIdentity,
        mailFromDomain.map(value => value),
        behaviorOnMxFailure.map(value => value)
      )
    def emailIdentity: Identity
    def mailFromDomain: Option[MailFromDomainName]
    def behaviorOnMxFailure
        : Option[zio.aws.pinpointemail.model.BehaviorOnMxFailure]
    def getEmailIdentity: ZIO[Any, Nothing, Identity] =
      ZIO.succeed(emailIdentity)
    def getMailFromDomain: ZIO[Any, AwsError, MailFromDomainName] =
      AwsError.unwrapOptionField("mailFromDomain", mailFromDomain)
    def getBehaviorOnMxFailure
        : ZIO[Any, AwsError, zio.aws.pinpointemail.model.BehaviorOnMxFailure] =
      AwsError.unwrapOptionField("behaviorOnMxFailure", behaviorOnMxFailure)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest
  ) extends zio.aws.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest.ReadOnly {
    override val emailIdentity: Identity =
      zio.aws.pinpointemail.model.primitives.Identity(impl.emailIdentity())
    override val mailFromDomain: Option[MailFromDomainName] = scala
      .Option(impl.mailFromDomain())
      .map(value =>
        zio.aws.pinpointemail.model.primitives.MailFromDomainName(value)
      )
    override val behaviorOnMxFailure
        : Option[zio.aws.pinpointemail.model.BehaviorOnMxFailure] = scala
      .Option(impl.behaviorOnMxFailure())
      .map(value => zio.aws.pinpointemail.model.BehaviorOnMxFailure.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest
  ): zio.aws.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-pinpointemail_2.12-6.20.103.1-sources.jar: zio/aws/pinpointemail/model/PutEmailIdentityMailFromAttributesRequest.scala <==
package zio.aws.pinpointemail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpointemail.model.primitives.{MailFromDomainName, Identity}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class PutEmailIdentityMailFromAttributesRequest(
    emailIdentity: Identity,
    mailFromDomain: Optional[MailFromDomainName] = Optional.Absent,
    behaviorOnMxFailure: Optional[
      zio.aws.pinpointemail.model.BehaviorOnMxFailure
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest = {
    import PutEmailIdentityMailFromAttributesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest
      .builder()
      .emailIdentity(Identity.unwrap(emailIdentity): java.lang.String)
      .optionallyWith(
        mailFromDomain.map(value =>
          MailFromDomainName.unwrap(value): java.lang.String
        )
      )(_.mailFromDomain)
      .optionallyWith(behaviorOnMxFailure.map(value => value.unwrap))(
        _.behaviorOnMxFailure
      )
      .build()
  }
  def asReadOnly
      : zio.aws.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest.ReadOnly =
    zio.aws.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest
      .wrap(buildAwsValue())
}
object PutEmailIdentityMailFromAttributesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest =
      zio.aws.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest(
        emailIdentity,
        mailFromDomain.map(value => value),
        behaviorOnMxFailure.map(value => value)
      )
    def emailIdentity: Identity
    def mailFromDomain: Optional[MailFromDomainName]
    def behaviorOnMxFailure
        : Optional[zio.aws.pinpointemail.model.BehaviorOnMxFailure]
    def getEmailIdentity: ZIO[Any, Nothing, Identity] =
      ZIO.succeed(emailIdentity)
    def getMailFromDomain: ZIO[Any, AwsError, MailFromDomainName] =
      AwsError.unwrapOptionField("mailFromDomain", mailFromDomain)
    def getBehaviorOnMxFailure
        : ZIO[Any, AwsError, zio.aws.pinpointemail.model.BehaviorOnMxFailure] =
      AwsError.unwrapOptionField("behaviorOnMxFailure", behaviorOnMxFailure)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest
  ) extends zio.aws.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest.ReadOnly {
    override val emailIdentity: Identity =
      zio.aws.pinpointemail.model.primitives.Identity(impl.emailIdentity())
    override val mailFromDomain: Optional[MailFromDomainName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.mailFromDomain())
        .map(value =>
          zio.aws.pinpointemail.model.primitives.MailFromDomainName(value)
        )
    override val behaviorOnMxFailure
        : Optional[zio.aws.pinpointemail.model.BehaviorOnMxFailure] =
      zio.aws.core.internal
        .optionalFromNullable(impl.behaviorOnMxFailure())
        .map(value =>
          zio.aws.pinpointemail.model.BehaviorOnMxFailure.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest
  ): zio.aws.pinpointemail.model.PutEmailIdentityMailFromAttributesRequest.ReadOnly =
    new Wrapper(impl)
}
